@@ -210,6 +210,7 @@ class Downloader:
                     ) as progress:
                         async with aiofiles.open(temp_file, mode='ab') as f:
                             async for chunk, _ in resp.content.iter_chunks():
+                                await asyncio.sleep(0)
                                 await f.write(chunk)
                                 progress.update(len(chunk))
             await self.rename_file(filename, url)
@@ -223,6 +224,8 @@ class Downloader:
             except:
                 pass
 
+            logger.debug(e)
+
             try:
                 logger.debug("Error status code: " + str(e.code))
                 if 400 <= e.code < 500 and e.code != 429:
